@@ -17,8 +17,8 @@
 
 use crate::ast::helpers::attached_token::AttachedToken;
 use crate::ast::{
-    BeginEndStatements, ConditionalStatementBlock, ConditionalStatements, GranteesType,
-    IfStatement, Statement, TriggerObject,
+    BeginEndStatements, ConditionalStatementBlock, ConditionalStatements, CreateTrigger,
+    GranteesType, IfStatement, Statement, TriggerObject,
 };
 use crate::dialect::Dialect;
 use crate::keywords::{self, Keyword};
@@ -226,12 +226,13 @@ impl MsSqlDialect {
             parser.prev_token();
         }
 
-        Ok(Statement::If(IfStatement {
+        Ok(IfStatement {
             if_block,
             else_block,
             elseif_blocks: Vec::new(),
             end_token: None,
-        }))
+        }
+        .into())
     }
 
     /// Parse `CREATE TRIGGER` for [MsSql]
@@ -251,12 +252,13 @@ impl MsSqlDialect {
         parser.expect_keyword_is(Keyword::AS)?;
         let statements = Some(parser.parse_conditional_statements(&[Keyword::END])?);
 
-        Ok(Statement::CreateTrigger {
+        Ok(CreateTrigger {
             or_alter,
             or_replace: false,
             is_constraint: false,
             name,
             period,
+            period_before_table: false,
             events,
             table_name,
             referenced_table_name: None,
@@ -265,9 +267,11 @@ impl MsSqlDialect {
             include_each: false,
             condition: None,
             exec_body: None,
+            statements_as: true,
             statements,
             characteristics: None,
-        })
+        }
+        .into())
     }
 
     /// Parse a sequence of statements, optionally separated by semicolon.
