@@ -15,7 +15,7 @@
 // specific language governing permissions and limitations
 // under the License.
 
-//! This module defines
+//! This module defines:
 //! 1) a list of constants for every keyword
 //! 2) an `ALL_KEYWORDS` array with every keyword in it
 //!    This is not a list of *reserved* keywords: some of these can be
@@ -76,10 +76,13 @@ define_keywords!(
     ABS,
     ABSENT,
     ABSOLUTE,
+    ACCEPTANYDATE,
+    ACCEPTINVCHARS,
     ACCESS,
     ACCOUNT,
     ACTION,
     ADD,
+    ADDQUOTES,
     ADMIN,
     AFTER,
     AGAINST,
@@ -90,6 +93,7 @@ define_keywords!(
     ALIAS,
     ALL,
     ALLOCATE,
+    ALLOWOVERWRITE,
     ALTER,
     ALWAYS,
     ANALYZE,
@@ -138,12 +142,14 @@ define_keywords!(
     BIND,
     BINDING,
     BIT,
+    BLANKSASNULL,
     BLOB,
     BLOCK,
     BLOOM,
     BLOOMFILTER,
     BOOL,
     BOOLEAN,
+    BOOST,
     BOTH,
     BOX,
     BRIN,
@@ -155,6 +161,7 @@ define_keywords!(
     BYPASSRLS,
     BYTEA,
     BYTES,
+    BZIP2,
     CACHE,
     CALL,
     CALLED,
@@ -166,6 +173,8 @@ define_keywords!(
     CAST,
     CATALOG,
     CATALOG_SYNC,
+    CATALOG_SYNC_NAMESPACE_FLATTEN_DELIMITER,
+    CATALOG_SYNC_NAMESPACE_MODE,
     CATCH,
     CEIL,
     CEILING,
@@ -184,6 +193,7 @@ define_keywords!(
     CHECK,
     CHECKSUM,
     CIRCLE,
+    CLEANPATH,
     CLEAR,
     CLOB,
     CLONE,
@@ -213,6 +223,7 @@ define_keywords!(
     CONNECTOR,
     CONNECT_BY_ROOT,
     CONSTRAINT,
+    CONTACT,
     CONTAINS,
     CONTINUE,
     CONVERT,
@@ -251,6 +262,7 @@ define_keywords!(
     DATA_RETENTION_TIME_IN_DAYS,
     DATE,
     DATE32,
+    DATEFORMAT,
     DATETIME,
     DATETIME64,
     DAY,
@@ -265,6 +277,7 @@ define_keywords!(
     DECLARE,
     DEDUPLICATE,
     DEFAULT,
+    DEFAULTS,
     DEFAULT_DDL_COLLATION,
     DEFERRABLE,
     DEFERRED,
@@ -285,6 +298,7 @@ define_keywords!(
     DETACH,
     DETAIL,
     DETERMINISTIC,
+    DIMENSIONS,
     DIRECTORY,
     DISABLE,
     DISCARD,
@@ -296,6 +310,7 @@ define_keywords!(
     DOMAIN,
     DOUBLE,
     DOW,
+    DOWNSTREAM,
     DOY,
     DROP,
     DRY,
@@ -307,9 +322,11 @@ define_keywords!(
     ELSE,
     ELSEIF,
     EMPTY,
+    EMPTYASNULL,
     ENABLE,
     ENABLE_SCHEMA_EVOLUTION,
     ENCODING,
+    ENCRYPTED,
     ENCRYPTION,
     END,
     END_EXEC = "END-EXEC",
@@ -336,6 +353,7 @@ define_keywords!(
     EXCEPTION,
     EXCHANGE,
     EXCLUDE,
+    EXCLUDING,
     EXCLUSIVE,
     EXEC,
     EXECUTE,
@@ -352,6 +370,7 @@ define_keywords!(
     EXTERNAL,
     EXTERNAL_VOLUME,
     EXTRACT,
+    FACTS,
     FAIL,
     FAILOVER,
     FALSE,
@@ -366,6 +385,8 @@ define_keywords!(
     FIRST,
     FIRST_VALUE,
     FIXEDSTRING,
+    FIXEDWIDTH,
+    FLATTEN,
     FLOAT,
     FLOAT32,
     FLOAT4,
@@ -396,6 +417,7 @@ define_keywords!(
     FUNCTIONS,
     FUSION,
     FUTURE,
+    GB,
     GENERAL,
     GENERATE,
     GENERATED,
@@ -411,6 +433,7 @@ define_keywords!(
     GROUP,
     GROUPING,
     GROUPS,
+    GZIP,
     HASH,
     HAVING,
     HEADER,
@@ -423,12 +446,14 @@ define_keywords!(
     HOUR,
     HOURS,
     HUGEINT,
+    IAM_ROLE,
     ICEBERG,
     ID,
     IDENTITY,
     IDENTITY_INSERT,
     IF,
     IGNORE,
+    IGNOREHEADER,
     ILIKE,
     IMMEDIATE,
     IMMUTABLE,
@@ -437,11 +462,14 @@ define_keywords!(
     IN,
     INCLUDE,
     INCLUDE_NULL_VALUES,
+    INCLUDING,
     INCREMENT,
+    INCREMENTAL,
     INDEX,
     INDICATOR,
     INHERIT,
     INHERITS,
+    INITIALIZE,
     INITIALLY,
     INNER,
     INOUT,
@@ -530,6 +558,7 @@ define_keywords!(
     MANAGE,
     MANAGED,
     MANAGEDLOCATION,
+    MANIFEST,
     MAP,
     MASKING,
     MATCH,
@@ -540,9 +569,11 @@ define_keywords!(
     MATERIALIZE,
     MATERIALIZED,
     MAX,
+    MAXFILESIZE,
     MAXVALUE,
     MAX_DATA_EXTENSION_TIME_IN_DAYS,
     MAX_ROWS,
+    MB,
     MEASURES,
     MEDIUMBLOB,
     MEDIUMINT,
@@ -553,6 +584,7 @@ define_keywords!(
     METADATA,
     METHOD,
     METRIC,
+    METRICS,
     MICROSECOND,
     MICROSECONDS,
     MILLENIUM,
@@ -584,6 +616,7 @@ define_keywords!(
     NATURAL,
     NCHAR,
     NCLOB,
+    NEST,
     NESTED,
     NETWORK,
     NEW,
@@ -608,6 +641,7 @@ define_keywords!(
     NOT,
     NOTHING,
     NOTIFY,
+    NOTNULL,
     NOWAIT,
     NO_WRITE_TO_BINLOG,
     NTH_VALUE,
@@ -632,6 +666,8 @@ define_keywords!(
     ON,
     ONE,
     ONLY,
+    ON_CREATE,
+    ON_SCHEDULE,
     OPEN,
     OPENJSON,
     OPERATE,
@@ -733,8 +769,10 @@ define_keywords!(
     REF,
     REFERENCES,
     REFERENCING,
+    REFRESH_MODE,
     REGCLASS,
     REGEXP,
+    REGION,
     REGR_AVGX,
     REGR_AVGY,
     REGR_COUNT,
@@ -744,6 +782,7 @@ define_keywords!(
     REGR_SXX,
     REGR_SXY,
     REGR_SYY,
+    REINDEX,
     RELATIVE,
     RELAY,
     RELEASE,
@@ -755,9 +794,11 @@ define_keywords!(
     REPAIR,
     REPEATABLE,
     REPLACE,
+    REPLACE_INVALID_CHARACTERS,
     REPLICA,
     REPLICATE,
     REPLICATION,
+    REQUIRE,
     RESET,
     RESOLVE,
     RESOURCE,
@@ -784,6 +825,7 @@ define_keywords!(
     ROLLUP,
     ROOT,
     ROW,
+    ROWGROUPSIZE,
     ROWID,
     ROWS,
     ROW_FORMAT,
@@ -804,9 +846,11 @@ define_keywords!(
     SECONDARY_ENGINE_ATTRIBUTE,
     SECONDS,
     SECRET,
+    SECURE,
     SECURITY,
     SEED,
     SELECT,
+    SEMANTIC_VIEW,
     SEMI,
     SENSITIVE,
     SEPARATOR,
@@ -869,6 +913,7 @@ define_keywords!(
     STORAGE_SERIALIZATION_POLICY,
     STORED,
     STRAIGHT_JOIN,
+    STREAM,
     STRICT,
     STRING,
     STRUCT,
@@ -894,6 +939,7 @@ define_keywords!(
     TABLESPACE,
     TAG,
     TARGET,
+    TARGET_LAG,
     TASK,
     TBLPROPERTIES,
     TEMP,
@@ -906,6 +952,7 @@ define_keywords!(
     THEN,
     TIES,
     TIME,
+    TIMEFORMAT,
     TIMESTAMP,
     TIMESTAMPTZ,
     TIMESTAMP_NTZ,
@@ -934,6 +981,7 @@ define_keywords!(
     TRIM_ARRAY,
     TRUE,
     TRUNCATE,
+    TRUNCATECOLUMNS,
     TRY,
     TRY_CAST,
     TRY_CONVERT,
@@ -1027,7 +1075,8 @@ define_keywords!(
     YEAR,
     YEARS,
     ZONE,
-    ZORDER
+    ZORDER,
+    ZSTD
 );
 
 /// These keywords can't be used as a table alias, so that `FROM table_name alias`
