@@ -1848,6 +1848,7 @@ fn parse_create_table_with_valid_options() {
                 temporary: false,
                 external: false,
                 global: None,
+                dynamic: false,
                 if_not_exists: false,
                 transient: false,
                 volatile: false,
@@ -1924,7 +1925,13 @@ fn parse_create_table_with_valid_options() {
                 catalog: None,
                 catalog_sync: None,
                 storage_serialization_policy: None,
-                table_options: CreateTableOptions::With(with_options)
+                table_options: CreateTableOptions::With(with_options),
+                target_lag: None,
+                warehouse: None,
+                version: None,
+                refresh_mode: None,
+                initialize: None,
+                require_user: false,
             })
         );
     }
@@ -2031,6 +2038,7 @@ fn parse_create_table_with_identity_column() {
                 temporary: false,
                 external: false,
                 global: None,
+                dynamic: false,
                 if_not_exists: false,
                 transient: false,
                 volatile: false,
@@ -2088,7 +2096,13 @@ fn parse_create_table_with_identity_column() {
                 catalog: None,
                 catalog_sync: None,
                 storage_serialization_policy: None,
-                table_options: CreateTableOptions::None
+                table_options: CreateTableOptions::None,
+                target_lag: None,
+                warehouse: None,
+                version: None,
+                refresh_mode: None,
+                initialize: None,
+                require_user: false,
             }),
         );
     }
@@ -2370,12 +2384,13 @@ fn parse_create_trigger() {
     let create_stmt = ms().verified_stmt(create_trigger);
     assert_eq!(
         create_stmt,
-        Statement::CreateTrigger {
+        Statement::CreateTrigger(CreateTrigger {
             or_alter: true,
             or_replace: false,
             is_constraint: false,
             name: ObjectName::from(vec![Ident::new("reminder1")]),
             period: TriggerPeriod::After,
+            period_before_table: false,
             events: vec![TriggerEvent::Insert, TriggerEvent::Update(vec![]),],
             table_name: ObjectName::from(vec![Ident::new("Sales"), Ident::new("Customer")]),
             referenced_table_name: None,
@@ -2384,6 +2399,7 @@ fn parse_create_trigger() {
             include_each: false,
             condition: None,
             exec_body: None,
+            statements_as: true,
             statements: Some(ConditionalStatements::Sequence {
                 statements: vec![Statement::RaisError {
                     message: Box::new(Expr::Value(
@@ -2401,7 +2417,7 @@ fn parse_create_trigger() {
                 }],
             }),
             characteristics: None,
-        }
+        })
     );
 
     let multi_statement_as_trigger = "\
@@ -2460,12 +2476,12 @@ fn parse_drop_trigger() {
     let drop_stmt = ms().one_statement_parses_to(sql_drop_trigger, "");
     assert_eq!(
         drop_stmt,
-        Statement::DropTrigger {
+        Statement::DropTrigger(DropTrigger {
             if_exists: false,
             trigger_name: ObjectName::from(vec![Ident::new("emp_stamp")]),
             table_name: None,
             option: None,
-        }
+        })
     );
 }
 
